swh-vault
=========

User-facing service that allows to retrieve parts of the archive as
self-contained bundles.

See the
[documentation](https://docs.softwareheritage.org/devel/swh-vault/index.html)
for more details.
